@@ -1,4 +1,4 @@
-"""
+'''
 # aws-events-rule-step-function module
 
 <!--BEGIN STABILITY BANNER-->---
@@ -96,7 +96,7 @@ Out of the box implementation of the Construct without any override will set the
 
 
 © Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-"""
+'''
 import abc
 import builtins
 import datetime
@@ -131,7 +131,7 @@ class EventsRuleToStepFunction(
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
     ) -> None:
-        """
+        '''
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
         :param event_rule_props: User provided eventRuleProps to override the defaults. Default: - None
@@ -142,7 +142,7 @@ class EventsRuleToStepFunction(
         :access: public
         :since: 0.9.0
         :summary: Constructs a new instance of the EventsRuleToStepFunction class.
-        """
+        '''
         props = EventsRuleToStepFunctionProps(
             event_rule_props=event_rule_props,
             state_machine_props=state_machine_props,
@@ -194,14 +194,14 @@ class EventsRuleToStepFunctionProps:
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
     ) -> None:
-        """
+        '''
         :param event_rule_props: User provided eventRuleProps to override the defaults. Default: - None
         :param state_machine_props: User provided StateMachineProps to override the defaults. Default: - None
         :param create_cloud_watch_alarms: Whether to create recommended CloudWatch alarms. Default: - Alarms are created
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
 
         :summary: The properties for the EventsRuleToStepFunction Construct
-        """
+        '''
         if isinstance(event_rule_props, dict):
             event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
         if isinstance(state_machine_props, dict):
@@ -219,39 +219,39 @@ class EventsRuleToStepFunctionProps:
 
     @builtins.property
     def event_rule_props(self) -> aws_cdk.aws_events.RuleProps:
-        """User provided eventRuleProps to override the defaults.
+        '''User provided eventRuleProps to override the defaults.
 
         :default: - None
-        """
+        '''
         result = self._values.get("event_rule_props")
         assert result is not None, "Required property 'event_rule_props' is missing"
         return typing.cast(aws_cdk.aws_events.RuleProps, result)
 
     @builtins.property
     def state_machine_props(self) -> aws_cdk.aws_stepfunctions.StateMachineProps:
-        """User provided StateMachineProps to override the defaults.
+        '''User provided StateMachineProps to override the defaults.
 
         :default: - None
-        """
+        '''
         result = self._values.get("state_machine_props")
         assert result is not None, "Required property 'state_machine_props' is missing"
         return typing.cast(aws_cdk.aws_stepfunctions.StateMachineProps, result)
 
     @builtins.property
     def create_cloud_watch_alarms(self) -> typing.Optional[builtins.bool]:
-        """Whether to create recommended CloudWatch alarms.
+        '''Whether to create recommended CloudWatch alarms.
 
         :default: - Alarms are created
-        """
+        '''
         result = self._values.get("create_cloud_watch_alarms")
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
     def log_group_props(self) -> typing.Optional[aws_cdk.aws_logs.LogGroupProps]:
-        """User provided props to override the default props for the CloudWatchLogs LogGroup.
+        '''User provided props to override the default props for the CloudWatchLogs LogGroup.
 
         :default: - Default props are used
-        """
+        '''
         result = self._values.get("log_group_props")
         return typing.cast(typing.Optional[aws_cdk.aws_logs.LogGroupProps], result)
 
